@@ -190,7 +190,7 @@ void BacktraceGenerator::setBackendPrepared()
     if (!m_tempDirectory->isValid()) {
         qCWarning(DRKONQI_LOG) << "Failed to create temporary directory for generator!";
     } else {
-#ifdef WITH_SENTRY
+#if WITH_SENTRY
         m_proc->setEnv(QStringLiteral("DRKONQI_WITH_SENTRY"), QStringLiteral("1"));
 #endif
         m_proc->setEnv(QStringLiteral("DRKONQI_TMP_DIR"), m_tempDirectory->path());
