@@ -1,6 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2009 George Kiagiadakis <gkiagia@users.sourceforge.net>
-    SPDX-FileCopyrightText: 2021 Harald Sitter <sitter@kde.org>
+    SPDX-FileCopyrightText: 2021-2022 Harald Sitter <sitter@kde.org>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -18,6 +18,19 @@ class KCrashBackend;
 class CrashedApplication : public QObject
 {
     Q_OBJECT
+    Q_PROPERTY(QString name READ name CONSTANT)
+    Q_PROPERTY(QFileInfo executable READ executable CONSTANT)
+    Q_PROPERTY(QString exectuableAbsoluteFilePath READ exectuableAbsoluteFilePath CONSTANT)
+    Q_PROPERTY(QString fakeExecutableBaseName READ fakeExecutableBaseName CONSTANT)
+    Q_PROPERTY(QString version READ version CONSTANT)
+    Q_PROPERTY(QString bugReportAddress READ bugReportAddress CONSTANT)
+    Q_PROPERTY(QString productName READ productName CONSTANT)
+    Q_PROPERTY(int pid READ pid CONSTANT)
+    Q_PROPERTY(int signalNumber READ signalNumber CONSTANT)
+    Q_PROPERTY(QString signalName READ signalName CONSTANT)
+    Q_PROPERTY(bool hasBeenRestarted READ hasBeenRestarted NOTIFY restarted)
+    Q_PROPERTY(QDateTime datetime READ datetime CONSTANT)
+    Q_PROPERTY(bool hasDeletedFiles READ hasDeletedFiles CONSTANT)
 public:
     CrashedApplication(int pid,
                        int thread,
@@ -41,6 +54,12 @@ public:
     /** Returns a QFileInfo with information about the executable that crashed */
     QFileInfo executable() const;
 
+    /** convenience wrapper to make access from QML easier */
+    QString exectuableAbsoluteFilePath() const
+    {
+        return m_executable.absoluteFilePath();
+    }
+
     /** When an application is run via kdeinit, the executable() method returns kdeinit4, but
      * we still need a way to know which is the application that was loaded by kdeinit. So,
      * this method returns the base name of the executable that would have been launched if
@@ -55,7 +74,7 @@ public:
     /** Returns the address where the bug report for this application should go */
     BugReportAddress bugReportAddress() const;
 
-    /** Bugzialla product name, if the crashed application has explicitly specified that. */
+    /** Bugzilla product name, if the crashed application has explicitly specified that. */
     QString productName() const;
 
     /** Returns the pid of the crashed program */
