@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2009 George Kiagiadakis <gkiagia@users.sourceforge.net>
+    SPDX-FileCopyrightText: 2021 Harald Sitter <sitter@kde.org>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,34 +11,41 @@
 #include "backtracegenerator.h"
 #include "debugger.h"
 #include "debuggerlaunchers.h"
+#include "drkonqibackends.h"
 
 struct DebuggerManager::Private {
-    BacktraceGenerator *btGenerator;
-    bool debuggerRunning;
+    BacktraceGenerator *btGenerator = nullptr;
+    bool debuggerRunning = false;
     QList<AbstractDebuggerLauncher *> externalDebuggers;
-    DBusInterfaceAdaptor *dbusInterfaceAdaptor;
+    DBusInterfaceAdaptor *dbusInterfaceAdaptor = nullptr;
 };
 
-DebuggerManager::DebuggerManager(const Debugger &internalDebugger, const QList<Debugger> &externalDebuggers, QObject *parent)
-    : QObject(parent)
+DebuggerManager::DebuggerManager(const Debugger &internalDebugger, const QList<Debugger> &externalDebuggers, AbstractDrKonqiBackend *backendParent)
+    : QObject(backendParent)
     , d(new Private)
 {
-    d->debuggerRunning = false;
     d->btGenerator = new BacktraceGenerator(internalDebugger, this);
     connect(d->btGenerator, &BacktraceGenerator::starting, this, &DebuggerManager::onDebuggerStarting);
     connect(d->btGenerator, &BacktraceGenerator::done, this, &DebuggerManager::onDebuggerFinished);
     connect(d->btGenerator, &BacktraceGenerator::someError, this, &DebuggerManager::onDebuggerFinished);
     connect(d->btGenerator, &BacktraceGenerator::failedToStart, this, &DebuggerManager::onDebuggerFinished);
+    connect(d->btGenerator, &BacktraceGenerator::preparing, backendParent, &AbstractDrKonqiBackend::prepareForDebugger);
+    connect(backendParent, &AbstractDrKonqiBackend::preparedForDebugger, d->btGenerator, &BacktraceGenerator::setBackendPrepared);
 
-    foreach (const Debugger &debugger, externalDebuggers) {
+    for (const Debugger &debugger : std::as_const(externalDebuggers)) {
         if (debugger.isInstalled()) {
             // TODO: use TerminalDebuggerLauncher instead
             addDebugger(new DefaultDebuggerLauncher(debugger, this));
         }
     }
 
-    // setup kdevelop compatibility
-    d->dbusInterfaceAdaptor = new DBusInterfaceAdaptor(this);
+    // DBus API to inject additional external debuggers at runtime. Used by KDevelop to add itself.
+    if (qobject_cast<KCrashBackend *>(backendParent)) {
+        // Runtime debugger injection is only allowed with KCrash because the API sports no interfaces for the debugger
+        // to describe its compatibility and it was introduced when only KCrash was around. To not have apps break
+        // randomly on different backends we require that our backend be KCrash.
+        d->dbusInterfaceAdaptor = new DBusInterfaceAdaptor(this);
+    }
 }
 
 DebuggerManager::~DebuggerManager()
@@ -79,30 +87,30 @@ void DebuggerManager::addDebugger(AbstractDebuggerLauncher *launcher, bool emits
     connect(launcher, &AbstractDebuggerLauncher::finished, this, &DebuggerManager::onDebuggerFinished);
     connect(launcher, &AbstractDebuggerLauncher::invalidated, this, &DebuggerManager::onDebuggerInvalidated);
     if (emitsignal) {
-        emit externalDebuggerAdded(launcher);
+        Q_EMIT externalDebuggerAdded(launcher);
     }
 }
 
 void DebuggerManager::onDebuggerStarting()
 {
     d->debuggerRunning = true;
-    emit debuggerStarting();
-    emit debuggerRunning(true);
+    Q_EMIT debuggerStarting();
+    Q_EMIT debuggerRunning(true);
 }
 
 void DebuggerManager::onDebuggerFinished()
 {
     d->debuggerRunning = false;
-    emit debuggerFinished();
-    emit debuggerRunning(false);
+    Q_EMIT debuggerFinished();
+    Q_EMIT debuggerRunning(false);
 }
 
 void DebuggerManager::onDebuggerInvalidated()
 {
-    AbstractDebuggerLauncher *launcher = qobject_cast<AbstractDebuggerLauncher *>(sender());
+    auto *launcher = qobject_cast<AbstractDebuggerLauncher *>(sender());
     Q_ASSERT(launcher);
     int index = d->externalDebuggers.indexOf(launcher);
     Q_ASSERT(index >= 0);
     d->externalDebuggers.removeAt(index);
-    emit externalDebuggerRemoved(launcher);
+    Q_EMIT externalDebuggerRemoved(launcher);
 }
