@@ -9,7 +9,6 @@
 
 #include "drkonqidialog.h"
 
-#include <KDeclarative/KDeclarative>
 #include <KLocalizedString>
 #include <KWindowConfig>
 
@@ -57,7 +56,6 @@ void DrKonqiDialog::show()
     static auto l10nContext = new KLocalizedContext(engine);
     l10nContext->setTranslationDomain(QStringLiteral(TRANSLATION_DOMAIN));
     engine->rootContext()->setContextObject(l10nContext);
-    KDeclarative::KDeclarative::setupEngine(engine);
 
     qmlRegisterType<BugzillaManager>("org.kde.drkonqi", 1, 0, "Bugzilla");
     qmlRegisterType<DuplicateModel>("org.kde.drkonqi", 1, 0, "DuplicateModel");
